==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QTabletEvent_shell.h <==
#ifndef QTABLETEVENT_SHELL_H
#define QTABLETEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QTabletEvent_shell : public QTabletEvent, public QtJambiShellInterface
{
public:
    QTabletEvent_shell(QEvent::Type t0, const QPointingDevice* device1, const QPointF& pos2, const QPointF& globalPos3, qreal pressure4, float xTilt5, float yTilt6, float tangentialPressure7, qreal rotation8, float z9, Qt::KeyboardModifiers keyState10, Qt::MouseButton button11, Qt::MouseButtons buttons12);
    QTabletEvent_shell(const QTabletEvent& arg__1);
    ~QTabletEvent_shell() override;

    QTabletEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTabletEvent_access : public QTabletEvent
{
    void __qt_assign_cref_QTabletEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setTangentialPressure_float(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jfloat tangentialPressure0);
};

#endif // QTABLETEVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QTabletEvent_shell.h <==
#ifndef QTABLETEVENT_SHELL_H
#define QTABLETEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QTabletEvent_shell : public QTabletEvent, public QtJambiShellInterface
{
public:
    QTabletEvent_shell(QEvent::Type t0, const QPointingDevice* device1, const QPointF& pos2, const QPointF& globalPos3, qreal pressure4, float xTilt5, float yTilt6, float tangentialPressure7, qreal rotation8, float z9, Qt::KeyboardModifiers keyState10, Qt::MouseButton button11, Qt::MouseButtons buttons12);
    QTabletEvent_shell(const QTabletEvent& arg__1);
    ~QTabletEvent_shell() override;

    QTabletEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTabletEvent_access : public QTabletEvent
{
    void __qt_assign_cref_QTabletEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setTangentialPressure_float(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jfloat tangentialPressure0);
};

#endif // QTABLETEVENT_SHELL_H
